# deluca

Performant, differentiable reinforcement learning

[![doc_coverage](https://raw.githubusercontent.com/MinRegret/deluca/main/.github/badges/docstring_coverage.svg?sanitize=true)](https://github.com/MinRegret/deluca)

![deluca](https://raw.githubusercontent.com/MinRegret/deluca/main/assets/img/deluca.svg?token=AAURLVRRLKHPK4VELPKH6X27RW5LC)
